<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Document Viewer</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Location</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Subject</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Author</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Keywords</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Producer</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Creator</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Time created</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Time modified</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Pages</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimized</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Security</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Page size</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>File size</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Yes</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Add bookmark</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Are you sure you want to delete all bookmarks?</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Remove annotation</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>Add annotation</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>Remove bookmark</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>Add bookmark</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Highlight</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Remove highlight</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>First page</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>Previous page</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>Next page</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>Last page</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>Rotate left</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>Rotate right</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>Document info</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="141"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>The format is not supported</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Open failed</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Please check if the file is damaged</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>Conversion failed, please check if the file is damaged</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Save failed</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Saved successfully</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Save as</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>Invalid file name</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Drag documents here</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Format supported: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Select File</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
        <source>The bookmark has been removed</source>
        <translation>The bookmark has been removed</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
        <source>Please select the text</source>
        <translation>Please select the text</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
        <source>The annotation has been removed</source>
        <translation>The annotation has been removed</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Encrypted file, please enter the password</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Wrong password</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="125"/>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="133"/>
        <source>Next</source>
        <translation>Next</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Select Text</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Hand Tool</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Add annotation</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Are you sure you want to delete all annotations?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Invalid page number</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>Converting</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Document not saved</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>Save the changes to &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Discard</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Two-Page View</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>1:1 size</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Fit Page</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Fit Height</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Fit Width</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="109"/>
        <source>%1 items found</source>
        <translation>%1 items found</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>This document is trying to connect to:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>If you trust the website, click Allow, otherwise click Block.</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>Block</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>Allow</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Thumbnails</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Catalog</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Bookmarks</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Annotations</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="58"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="79"/>
        <source>Files</source>
        <translation>Files</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Tools</source>
        <translation>Tools</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <source>Zoom in/Zoom out</source>
        <translation>Zoom in/Zoom out</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Save as</source>
        <translation>Save as</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Thumbnails</source>
        <translation>Thumbnails</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>1:1 size</source>
        <translation>1:1 size</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit height</source>
        <translation>Fit height</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit width</source>
        <translation>Fit width</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate left</source>
        <translation>Rotate left</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate right</source>
        <translation>Rotate right</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Select text</source>
        <translation>Select text</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Hand tool</source>
        <translation>Hand tool</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add bookmark</source>
        <translation>Add bookmark</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Magnifier</source>
        <translation>Magnifier</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add annotation</source>
        <translation>Add annotation</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Highlight</source>
        <translation>Highlight</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Remove annotation</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>Remove all</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Remove bookmark</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Page %1</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>New window</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>New tab</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Save as</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Magnifer</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Tools</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation type="unfinished">Print</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Thumbnails</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Input limit reached</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Document File Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>FilePath</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generate thumbnail.</translation>
    </message>
</context>
</TS>
